@@ -4,11 +4,10 @@ use 5.00503;
 use strict;
 use warnings;
 require Exporter;
-use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
-@ISA       = qw(Exporter);
-@EXPORT    = qw(cp rm_f rm_rf mv cat eqtime mkpath touch test_f test_d chmod
-                dos2unix);
-$VERSION = '7.66';
+our @ISA     = qw(Exporter);
+our @EXPORT  = qw(cp rm_f rm_rf mv cat eqtime mkpath touch test_f test_d chmod
+                  dos2unix);
+our $VERSION = '7.70';
 $VERSION =~ tr/_//d;
 
 my $Is_VMS   = $^O eq 'VMS';
