@@ -167,22 +167,7 @@ EOF
 	*"-c99: Unknown flag"*)
 		_ccflags_strict_ansi="-std1"
 		;;
-	*)	# However, use the -c99 only if compiling for
-		# -DPERL_MEM_LOG, where the C99 feature __func__
-		# is useful to have.  Otherwise use the good old
-		# -std1 so that we stay C89 strict, which the goal
-		# of the Perl C code base (no //, no code between
-		# declarations, etc).  Moreover, the Tru64 cc is
-		# not fully C99, and most probably never will be.
-		#
-		# The -DPERL_MEM_LOG can be either in ccflags
-		# (if using an old config.sh) or in the command line
-		# (which has been stowed away in UU/cmdline.opt).
-		#
-		case "$ccflags `cat UU/cmdline.opt`" in
-		*-DPERL_MEM_LOG*)	_ccflags_strict_ansi="-c99"  ;;
-		*)			_ccflags_strict_ansi="-std1" ;;
-		esac
+	*)	_ccflags_strict_ansi="-c99"
 		;;
 	esac
 	_lddlflags_strict_ansi="-std1"
@@ -278,7 +263,7 @@ toke_cflags='optimize=-O2'
 esac
 
 # The patch 23787
-# http://perl5.git.perl.org/perl.git/commit/73cb726371990cd489597c4fee405a9815abf4da
+# https://github.com/Perl/perl5/commit/73cb726371990cd489597c4fee405a9815abf4da
 # broke things for gcc (at least gcc 3.3) so that many of the pack()
 # checksum tests for formats L, j, J, especially when combined
 # with the < and > specifiers, started to fail if compiled with plain -O3.
@@ -502,7 +487,7 @@ esac
 for p in $loclibpth
 do
 	if test -d $p; then
-	    echo "Appending $p to LD_LIBRARY_PATH." >& 4
+	    echo "Appending $p to LD_LIBRARY_PATH." >&4
 	    case "$LD_LIBRARY_PATH" in
 	    '') LD_LIBRARY_PATH=$p                  ;;
 	    *)  LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$p ;;
@@ -511,7 +496,7 @@ do
 done
 case "$LD_LIBRARY_PATH" in
 "$old_LD_LIBRARY_PATH") ;;
-*) echo "LD_LIBRARY_PATH is now $LD_LIBRARY_PATH." >& 4 ;;
+*) echo "LD_LIBRARY_PATH is now $LD_LIBRARY_PATH." >&4 ;;
 esac
 case "$LD_LIBRARY_PATH" in
 '') ;;
@@ -571,6 +556,7 @@ d_nan='undef'
 d_nearbyint='undef'
 d_round='undef'
 d_scalbn='undef'
+d_tgamma='undef'
 
 #
 # Unset temporary variables no more needed.
